@@ -1,4 +1,4 @@
-import threading
+from datetime import datetime
 from time import time
 from typing import Callable
 
@@ -21,17 +21,16 @@ class Analytics(BaseHTTPMiddleware):
         start = time()
         response = call_next(request)
 
-        data = {
-            'api_key': self.api_key,
+        request_data = {
             'hostname': request.host,
             'ip_address': request.remote_addr,
             'path': request.path,
             'user_agent': request.headers['user-agent'],
             'method': request.method,
             'status': response.status_code,
-            'framework': 'Flask',
             'response_time': int((time() - start) * 1000),
+            'created_at': datetime.now().isoformat()
         }
-        
-        threading.Thread(target=log_request, args=(data,)).start()
+
+        log_request(self.api_key, request_data, 'Flask')
         return response
